TinyXml: Class List

# Class List

Here are the classes, structs, unions and interfaces with brief descriptions:

TiXmlAttribute | An attribute is a name-value pair
TiXmlBase | TiXmlBase is a base class for every class in TinyXml
TiXmlComment | An XML comment
TiXmlDeclaration | In correct XML the declaration is the first entry in the file
TiXmlDocument | Always the top level node
TiXmlElement | The element is a container class
TiXmlHandle | A TiXmlHandle is a class that wraps a node pointer with null checks; this is an incredibly useful thing
TiXmlNode | The parent class for everything in the Document Object Model
TiXmlPrinter | Print to memory functionality
TiXmlText | XML text
TiXmlUnknown | Any tag that tinyXml doesn't recognize is saved as an unknown
TiXmlVisitor | Implements the interface to the "Visitor pattern" (see the Accept() method